@@ -18,14 +18,18 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
+/* FIXME: gdk_gc_* needs porting to cairo */
+#undef GDK_DISABLE_DEPRECATED
+
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <panel-applet.h>
 #include <gtk/gtk.h>
