@@ -38,6 +38,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <gconf/gconf-client.h>
 #include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
@@ -54,7 +55,7 @@ static void     gpm_tray_icon_finalize   (GObject	   *object);
 
 struct GpmTrayIconPrivate
 {
-	GSettings		*settings;
+	GConfClient		*conf;
 	GpmEngine		*engine;
 	GtkStatusIcon		*status_icon;
 	gboolean		 show_actions;
@@ -94,7 +95,11 @@ gpm_tray_icon_set_tooltip (GpmTrayIcon *icon, const gchar *tooltip)
 	g_return_val_if_fail (GPM_IS_TRAY_ICON (icon), FALSE);
 	g_return_val_if_fail (tooltip != NULL, FALSE);
 
+#if GTK_CHECK_VERSION(2,15,0)
 	gtk_status_icon_set_tooltip_text (icon->priv->status_icon, tooltip);
+#else
+	gtk_status_icon_set_tooltip (icon->priv->status_icon, tooltip);
+#endif
 	return TRUE;
 }
 
@@ -115,16 +120,14 @@ gpm_tray_icon_get_status_icon (GpmTrayIcon *icon)
  * Loads a pixmap from disk, and sets as the tooltip icon
  **/
 gboolean
-gpm_tray_icon_set_icon (GpmTrayIcon *icon, GIcon *gicon)
+gpm_tray_icon_set_icon (GpmTrayIcon *icon, const gchar *filename)
 {
-	gchar *filename = NULL;
 	g_return_val_if_fail (icon != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_TRAY_ICON (icon), FALSE);
 
-	if (gicon != NULL) {
-		filename = g_icon_to_string (gicon);
+	if (filename != NULL) {
 		egg_debug ("Setting icon to %s", filename);
-		gtk_status_icon_set_from_gicon (icon->priv->status_icon, gicon);
+		gtk_status_icon_set_from_icon_name (icon->priv->status_icon, filename);
 
 		/* make sure that we are visible */
 		gpm_tray_icon_show (icon, TRUE);
@@ -135,7 +138,6 @@ gpm_tray_icon_set_icon (GpmTrayIcon *icon, GIcon *gicon)
 		/* make sure that we are hidden */
 		gpm_tray_icon_show (icon, FALSE);
 	}
-	g_free (filename);
 	return TRUE;
 }
 
@@ -168,6 +170,21 @@ gpm_tray_icon_show_preferences_cb (GtkMenuItem *item, gpointer data)
 		egg_warning ("Couldn't execute command: %s", command);
 }
 
+/**
+ * gpm_tray_icon_popup_cleared_cd:
+ * @widget: The popup Gtkwidget
+ *
+ * We have to re-enable the tooltip when the popup is removed
+ **/
+static void
+gpm_tray_icon_popup_cleared_cd (GtkWidget *widget, GpmTrayIcon *icon)
+{
+	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
+	egg_debug ("clear tray");
+	g_object_ref_sink (widget);
+	g_object_unref (widget);
+}
+
 /**
  * gpm_tray_icon_class_init:
  **/
@@ -188,19 +205,15 @@ gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *arr
 {
 	guint i;
 	guint added = 0;
-	gchar *percentage_str;
+	gchar *icon_name;
+	gchar *label;
 	GtkWidget *item;
-	GtkWidget *label_title;
-	GtkWidget *label_percentage;
 	GtkWidget *image;
-	GtkWidget *hbox;
-	GtkWidget *hbox_align;
 	const gchar *object_path;
 	const gchar *desc;
 	UpDevice *device;
 	UpDeviceKind kind_tmp;
 	gdouble percentage;
-	GIcon *gicon = NULL;
 
 	/* find type */
 	for (i=0;i<array->len;i++) {
@@ -219,98 +232,41 @@ gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *arr
 		egg_debug ("adding device %s", object_path);
 		added++;
 
-		/* generate the labels */
-		desc = gpm_device_kind_to_localised_string (kind, 1);
-		percentage_str = g_strdup_printf ("%.0f%%", percentage);
-
-		/* align title and percentage in columns */
-		hbox = gtk_hbox_new (FALSE, 3);
-		gtk_widget_show (hbox);
-
-		/* left align the device text */
-		hbox_align = gtk_hbox_new (FALSE, 0);
-		gtk_widget_show (hbox_align);
-		label_title = gtk_label_new (desc);
-		gtk_widget_show (label_title);
-		gtk_box_pack_start (GTK_BOX (hbox_align), label_title, FALSE, FALSE, 0);
-
-		/* center align the percentage */
-		label_percentage = gtk_label_new (percentage_str);
-		gtk_widget_show (label_percentage);
-
-		/* add to the menu item */
-		item = gtk_image_menu_item_new ();
-		gtk_container_add (GTK_CONTAINER (item), hbox);
-		gtk_box_pack_start (GTK_BOX (hbox), hbox_align, TRUE, TRUE, 3);
-		gtk_box_pack_start (GTK_BOX (hbox), label_percentage, FALSE, FALSE, 3);
+		/* generate the label */
+		desc = gpm_device_kind_to_localised_text (kind, 1);
+		label = g_strdup_printf ("%s (%.1f%%)", desc, percentage);
+		item = gtk_image_menu_item_new_with_label (label);
 
 		/* generate the image */
-		gicon = gpm_upower_get_device_icon (device, TRUE);
-		image = gtk_image_new_from_gicon (gicon, GTK_ICON_SIZE_MENU);
+		icon_name = gpm_upower_get_device_icon (device);
+		image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (item), TRUE);
 
 		/* callback and add the the menu */
 		g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (gpm_tray_icon_show_info_cb), icon);
 		g_object_set_data (G_OBJECT (item), "object-path", (gpointer) object_path);
-
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-		g_free (percentage_str);
-		g_object_unref (gicon);
+		g_free (icon_name);
+		g_free (label);
 	}
 	return added;
 }
 
-/**
- * gpm_tray_icon_add_primary_device:
- **/
-static void
-gpm_tray_icon_add_primary_device (GpmTrayIcon *icon, GtkMenu *menu, UpDevice *device)
-{
-	GtkWidget *item;
-	gchar *time_str;
-	gchar *string;
-	gint64 time_to_empty = 0;
-
-	/* get details */
-	g_object_get (device,
-		      "time-to-empty", &time_to_empty,
-		      NULL);
-
-	/* convert time to string */
-	time_str = gpm_get_timestring (time_to_empty);
-
-	/* TRANSLATORS: % is a timestring, e.g. "6 hours 10 minutes" */
-	string = g_strdup_printf (_("%s remaining"), time_str);
-	item = gtk_image_menu_item_new_with_label (string);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	g_free (time_str);
-	g_free (string);
-}
-
 /**
  * gpm_tray_icon_create_menu:
  *
- * Create the popup menu.
+ * Display the popup menu.
  **/
-static GtkMenu *
-gpm_tray_icon_create_menu (GpmTrayIcon *icon)
+static void
+gpm_tray_icon_create_menu (GpmTrayIcon *icon, guint32 timestamp)
 {
 	GtkMenu *menu = (GtkMenu*) gtk_menu_new ();
 	GtkWidget *item;
 	GtkWidget *image;
 	guint dev_cnt = 0;
 	GPtrArray *array;
-	UpDevice *device = NULL;
-
-	/* show the primary device time remaining */
-	device = gpm_engine_get_primary_device (icon->priv->engine);
-	if (device != NULL) {
-		gpm_tray_icon_add_primary_device (icon, menu, device);
-		item = gtk_separator_menu_item_new ();
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	}
 
 	/* add all device types to the drop down menu */
 	array = gpm_engine_get_devices (icon->priv->engine);
@@ -346,38 +302,6 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon)
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 skip_prefs:
-	if (device != NULL)
-		g_object_unref (device);
-	return menu;
-}
-
-/**
- * gpm_tray_icon_popup_cleared_cd:
- * @widget: The popup Gtkwidget
- *
- * We have to re-enable the tooltip when the popup is removed
- **/
-static void
-gpm_tray_icon_popup_cleared_cd (GtkWidget *widget, GpmTrayIcon *icon)
-{
-	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
-	egg_debug ("clear tray");
-	g_object_ref_sink (widget);
-	g_object_unref (widget);
-}
-
-/**
- * gpm_tray_icon_popup_menu:
- *
- * Display the popup menu.
- **/
-static void
-gpm_tray_icon_popup_menu (GpmTrayIcon *icon, guint32 timestamp)
-{
-	GtkMenu *menu;
-
-	menu = gpm_tray_icon_create_menu (icon);
-
 	/* show the menu */
 	gtk_widget_show_all (GTK_WIDGET (menu));
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
@@ -397,7 +321,7 @@ static void
 gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 timestamp, GpmTrayIcon *icon)
 {
 	egg_debug ("icon right clicked");
-	gpm_tray_icon_popup_menu (icon, timestamp);
+	gpm_tray_icon_create_menu (icon, timestamp);
 }
 
 
@@ -411,21 +335,26 @@ static void
 gpm_tray_icon_activate_cb (GtkStatusIcon *status_icon, GpmTrayIcon *icon)
 {
 	egg_debug ("icon left clicked");
-	gpm_tray_icon_popup_menu (icon, gtk_get_current_event_time());
+	gpm_tray_icon_create_menu (icon, gtk_get_current_event_time());
 }
 
 /**
- * gpm_tray_icon_settings_changed_cb:
+ * gpm_conf_gconf_key_changed_cb:
  *
- * We might have to do things when the settings change; do them here.
+ * We might have to do things when the gconf keys change; do them here.
  **/
 static void
-gpm_tray_icon_settings_changed_cb (GSettings *settings, const gchar *key, GpmTrayIcon *icon)
+gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmTrayIcon *icon)
 {
+	GConfValue *value;
 	gboolean allowed_in_menu;
 
-	if (g_strcmp0 (key, GPM_SETTINGS_SHOW_ACTIONS) == 0) {
-		allowed_in_menu = g_settings_get_boolean (settings, key);
+	value = gconf_entry_get_value (entry);
+	if (value == NULL)
+		return;
+
+	if (strcmp (entry->key, GPM_CONF_UI_SHOW_ACTIONS) == 0) {
+		allowed_in_menu = gconf_value_get_bool (value);
 		gpm_tray_icon_enable_actions (icon, allowed_in_menu);
 	}
 }
@@ -444,9 +373,13 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 
 	icon->priv->engine = gpm_engine_new ();
 
-	icon->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
-	g_signal_connect (icon->priv->settings, "changed",
-			  G_CALLBACK (gpm_tray_icon_settings_changed_cb), icon);
+	icon->priv->conf = gconf_client_get_default ();
+	/* watch gnome-power-manager keys */
+	gconf_client_add_dir (icon->priv->conf, GPM_CONF_DIR,
+			      GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
+	gconf_client_notify_add (icon->priv->conf, GPM_CONF_DIR,
+				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
+				 icon, NULL, NULL);
 
 	icon->priv->status_icon = gtk_status_icon_new ();
 	g_signal_connect_object (G_OBJECT (icon->priv->status_icon),
@@ -458,7 +391,7 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 				 G_CALLBACK (gpm_tray_icon_activate_cb),
 				 icon, 0);
 
-	allowed_in_menu = g_settings_get_boolean (icon->priv->settings, GPM_SETTINGS_SHOW_ACTIONS);
+	allowed_in_menu = gconf_client_get_bool (icon->priv->conf, GPM_CONF_UI_SHOW_ACTIONS, NULL);
 	gpm_tray_icon_enable_actions (icon, allowed_in_menu);
 }
 
